@@ -10,6 +10,7 @@
 #undef CATALOG3
 #undef EJECT
 #undef HOST_OS
+#undef USE_PTHREADS
 
 @BOTTOM@
 #define DEFAULTFILEICONPATH DATA_DIR "/gtktalog/icons/default_file.xpm"
@@ -17,3 +18,6 @@
 #define DEFAULTDIRICONPATH DATA_DIR "/gtktalog/icons/default_dir.xpm"
 #define DEFAULTUNREADABLEICONPATH DATA_DIR "/gtktalog/icons/default_unreadable.xpm"
 #define DEFAULTVFSICONPATH DATA_DIR "/gtktalog/icons/default_vfs.xpm"
+#define DEFAULTOPENEDDISKICONPATH DATA_DIR "/gtktalog/icons/default_opened_disk.xpm"
+#define DEFAULTOPENEDDIRICONPATH DATA_DIR "/gtktalog/icons/default_opened_dir.xpm"
+#define DEFAULTOPENEDVFSICONPATH DATA_DIR "/gtktalog/icons/default_opened_vfs.xpm"
