@@ -29,7 +29,9 @@
 #include <time.h>
 #include <stdio.h>
 #include <string.h>
-#include <pthread.h>
+#if defined(USE_PTHREADS)
+#    include <pthread.h>
+#endif
 #include <signal.h>
 
 #include "addisk.h"
@@ -63,7 +65,8 @@ static GString *message_to_display;
 
 static gboolean vfs_scan_nok;
 
-gint spawn_proc (gchar * path, gint narg, gchar ** arg)
+gint
+spawn_proc (gchar * path, gint narg, gchar ** arg)
 {
   gchar **arg2;
   int i, pid;
@@ -93,7 +96,8 @@ gint spawn_proc (gchar * path, gint narg, gchar ** arg)
     }
 }
 
-guint du_s (gchar * path)
+guint
+du_s (gchar * path)
 {
   int p[2];
   static gchar buffer[1024];
@@ -111,7 +115,11 @@ guint du_s (gchar * path)
 	   * in order not to have error messages on the console
 	   */
 	  argsdu[0] = g_strdup ("du");
+#if defined(OS_LINUX)
 	  argsdu[1] = g_strdup ("-sb");
+#elif defined(OS_FREEBSD) || defined(OS_NETBSD)
+	  argsdu[1] = g_strdup ("-s");
+#endif
 	  argsdu[2] = path;
 	  argsdu[3] = NULL;
 	  execvp (argsdu[0], argsdu);
@@ -163,8 +171,7 @@ set_message_to_display (GString * message)
   is_message_to_display = TRUE;
 }
 
-gboolean
-eject_disk (CONFIG * my_config)
+gboolean eject_disk (CONFIG * my_config)
 {
   int status, pid;
   char *args[2];
@@ -196,9 +203,9 @@ eject_disk (CONFIG * my_config)
   return (TRUE);
 }
 
-gboolean
-mount_disk (CONFIG * my_config)
+gboolean mount_disk (CONFIG * my_config)
 {
+#if defined(OS_LINUX)
   int pid, status;
   char *args[2];
 
@@ -227,11 +234,26 @@ mount_disk (CONFIG * my_config)
       return (FALSE);
     }
   return (TRUE);
+#elif defined(OS_FREEBSD) || defined(OS_NETBSD)
+  int status;
+  struct iso_args args;
+
+  args.export.ex_flags = MNT_EXRDONLY;
+  args.fspec = "/dev/cd0a";	// Will be changed
+  args.export.ex_root = -2;
+  status =
+    mount (MOUNT_CD9660, my_config->mount_point->str, MNT_RDONLY, &args);
+  /* error saved in errno variable, do something with it */
+  if (status == 0)
+    return (TRUE);
+  else
+    return (FALSE);
+#endif
 }
 
-gboolean
-umount_disk (CONFIG * my_config)
+gboolean umount_disk (CONFIG * my_config)
 {
+#if defined(OS_LINUX)
   int pid, status;
   char *args[2];
 
@@ -261,6 +283,15 @@ umount_disk (CONFIG * my_config)
       return (FALSE);
     }
   return (TRUE);
+#elif defined(OS_FREEBSD) || defined(OS_NETBSD)
+  int status;
+
+  status = unmount (my_config->mount_point->str, NULL);
+  if (status == 0)
+    return (TRUE);
+  else
+    return (FALSE);
+#endif
 }
 
 void
@@ -305,8 +336,7 @@ init_vfs_scan_status (void)
   vfs_scan_nok = FALSE;
 }
 
-gint
-my_timeout (gpointer data)
+gint my_timeout (gpointer data)
 {
   FOLDER *racine = data;
 /*  FILE_DATA *fd;*/
@@ -339,7 +369,8 @@ my_timeout (gpointer data)
       reinit_thread_status ();
       if (vfs_scan_nok)
 	{
-	  WARNING_DIALOG (_("At least one VFS could not be read successfully"),
+	  WARNING_DIALOG (_
+			  ("At least one VFS could not be read successfully"),
 			  main_window);
 	}
     }
@@ -473,8 +504,7 @@ read_information (gchar * file, gchar * mime)
   return (information_string);
 }
 
-gboolean
-is_dir_openable (char *dir_name)
+gboolean is_dir_openable (char *dir_name)
 {
   DIR *dir;
 
@@ -519,10 +549,10 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 
   if ((dir = opendir (my_path->str)) == NULL)
     {
-      printf ("ne peut lister le repertoire courant: %s", my_path->str);
+      /* FIXME: put an English message inside a dialog box */
+      printf ("Can't read the directory: %s", my_path->str);
       return (FALSE);
     }
-
   while ((fichier = readdir (dir)) != NULL)
     {
       file = g_strconcat (my_path->str, fichier->d_name, NULL);
@@ -536,7 +566,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 			       IS_UNREADABLE, NULL, 0, 0, 0, 0);
 	    }
 	  /* This is a directory */
-	  if (S_ISLNK (fileinfo.st_mode))
+	  else if (S_ISLNK (fileinfo.st_mode))
 	    {
 	      char tmp[1024];
 	      char tmp2[2048];
@@ -576,12 +606,13 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 	      totalDataBlocks += fileinfo.st_size;
 	      progress_setCurrent (totalDataBlocks);
 
+	      mime = NULL;
 	      if (my_config->scan_mime_types)
 		{
 		  mime = g_strdup (gnome_mime_type_from_magic (file));
 		}
-	      else
-		mime = g_strdup (gnome_mime_type_or_default (file, NULL));;
+	      if (!mime)
+		mime = g_strdup (gnome_mime_type_or_default (file, NULL));
 
 	      if (getInformation)
 		{
@@ -607,9 +638,12 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
 	    }
 	}
       free (file);
+#if !defined(USE_PTHREADS)
+      gui_update ();
+#endif
+
     }
   closedir (dir);
-
   while (new_dirs)
     {
       gn = (GNode *) new_dirs->data;
@@ -624,8 +658,7 @@ create_folder_tree (FOLDER * racine, GNode * parent, const gchar * path,
   return (vfs_scan_nok);
 }
 
-gboolean
-check_mounted (CONFIG * my_config)
+gboolean check_mounted (CONFIG * my_config)
 {
   FILE *fp;
   char line[1024];
@@ -666,7 +699,9 @@ start_thread_scan (void *arg)
 {
   FOLDER *racine = arg;
   init_message_to_display ();
+#if defined(USE_PTHREADS)
   pthread_detach (pthread_self ());
+#endif
 
   /* Mount the CD if we are in fastadddisk */
   flag_to_umount = FALSE;
@@ -693,7 +728,9 @@ start_thread_scan (void *arg)
 		    ("FIXME: Add error message for error in mounting CD\n");
 		  added_disk_is_ok = ADDED_DISK_NOK;
 		  set_thread_status_to_ended ();
+#if defined(USE_PTHREADS)
 		  pthread_exit (NULL);
+#endif
 		  return (NULL);
 		}
 	      else
@@ -714,6 +751,9 @@ start_thread_scan (void *arg)
   local_gn =
     folder_add (racine, racine->tree,
 		local_diskname, local_foldername, IS_DISK, NULL, 0, 0, 0, 0);
+#if !defined(USE_PTHREADS)
+  gui_update ();
+#endif
   vfs_scan_nok = create_folder_tree (racine, local_gn, local_foldername,
 				     my_config->getInformation,
 				     my_config->testvfs);
@@ -721,7 +761,9 @@ start_thread_scan (void *arg)
   umount_and_eject_if_necessary ();
   set_thread_status_to_ended ();
   racine->is_modified = TRUE;
+#if defined(USE_PTHREADS)
   pthread_exit (NULL);
+#endif
   return (NULL);
 }
 
