@@ -187,8 +187,7 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 /*****************************************************************************************/
 
 
-gint
-find_viewer (gpointer key, gpointer value, gpointer data)
+gint find_viewer (gpointer key, gpointer value, gpointer data)
 {
   struct mime_and_string *_find_mime = data;
   MIME_EXTENSIONS *m = value;
@@ -374,7 +373,7 @@ main_window);
 		      else
 			{
 			  ERROR_DIALOG (_
-					("The filename contains '%f'. This conflicts with the viewer definition."),
+					("The filename contains `%f'. This conflicts with the viewer definition."),
 main_window);
 
 			}
@@ -488,7 +487,8 @@ rm_tree (GNode * gn, FOLDER * racine)
   gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
 }
 
-gboolean set_vfs_fd (GNode * gn, gpointer data)
+gboolean
+set_vfs_fd (GNode * gn, gpointer data)
 {
   FILE_DATA *fd = get_file_data_from_gnode (gn);
   fd->a_parent_node_is_vfs = IS_VFS;
@@ -596,8 +596,7 @@ GnomeUIInfo clist_pressed_menu_file[] = {
   GNOMEUIINFO_END
 };
 
-gint
-cmp_2file_types (GNode * gn1, GNode * gn2)
+gint cmp_2file_types (GNode * gn1, GNode * gn2)
 {
   if (G_NODE_IS_ROOT (gn1->parent))
     return (-1);
@@ -1213,6 +1212,18 @@ add_file_menu (gchar * fullname)
   update_file_menu ();
 }
 
+void
+menus_set_sensitive (gboolean sensitive)
+{
+  gtk_widget_set_sensitive (GTK_WIDGET (file_menu[2].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (file_menu[3].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (edit_menu[0].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (edit_menu[1].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (action_menu[0].widget), sensitive);
+  gtk_widget_set_sensitive (GTK_WIDGET (action_menu[1].widget), sensitive);
+  buttons_set_sensitive (sensitive);
+}
+
 void
 build_gui (void)
 {
@@ -1229,7 +1240,8 @@ build_gui (void)
 
   gnome_app_create_menus_with_data (GNOME_APP (main_window), menubar, NULL);
   enable_gnome_button_bar (main_window, NULL);
-
+  gtk_menu_item_right_justify (GTK_MENU_ITEM (menubar[3].widget));
+  menus_set_sensitive (FALSE);
   update_file_menu ();
 
 /* Status and progress bar */
