@@ -24,18 +24,18 @@
 
 #include "config_common.h"
 
-
+PIX *get_pix_from_gnode (GNode * gn);
 gboolean add_gnode_to_ctree (GNode * gn, gpointer data);
 void open_cat_ok_sel(GtkWidget *w, gpointer data);
 void open_cat (FOLDER *racine);
+void expand_folder (GNode * gn);
 void create_tree(FOLDER *racine);
-FOLDER *init_folder(void);
 void new_file();
-void clear_folder(FOLDER *racine);
 void save_cat_ok_sel(GtkWidget *w, FOLDER *racine);
 void save_cat(FOLDER *racine);
 void fast_save(FOLDER *racine);
 const gint string_to_index(GPtrArray *a, gchar *s);
+gboolean test_plugin_existence(GString *filename);
 
 #endif
 /* io.c */
