@@ -31,8 +31,7 @@ progress_reset ()
   progress_INeedReset = FALSE;
 }
 
-gboolean
-progress_needReset ()
+gboolean progress_needReset ()
 {
   return progress_INeedReset;
 }
@@ -41,8 +40,7 @@ progress_needReset ()
    FIXME: Will take the size of the current filesystem.
         That means it won't work if you only try to catalog a part of a drive
 */
-glong
-getStats (char *foldername)
+glong getStats (char *foldername)
 {
   struct statfs statBuf;
 
@@ -62,8 +60,7 @@ progress_createTimeout ()
 
 /* Update the progress_bar.
    The progress bar must be passed with a gpointer */
-gint
-progress_timeout (gpointer pstru)
+gint progress_timeout (gpointer pstru)
 {
   gfloat new_val;
 
@@ -72,7 +69,7 @@ progress_timeout (gpointer pstru)
   /* Set the new value */
   if (new_val > 0.99)
     new_val = 1;
-  if (new_val > 0)
+  if (new_val >= 0)
     gnome_appbar_set_progress (GNOME_APPBAR (progress_appbar), new_val);
 
   /* Stop the timer */
@@ -100,7 +97,8 @@ progress_setCurrent (gulong current)
   progress_currentValue = current;
 }
 
-gulong progress_getCurrent ()
+gulong
+progress_getCurrent ()
 {
   return progress_currentValue;
 }
