@@ -23,9 +23,10 @@
 #ifdef OS_LINUX
 #  include <sys/vfs.h>		
 #endif
-#ifdef OS_FREEBSD
+#if defined(OS_FREEBSD) || defined(OS_NETBSD)
 #    include <sys/param.h>
 #    include <sys/mount.h>
+#    include <isofs/cd9660/cd9660_mount.h>
 #endif
 #include <gnome.h>
 
